Module digest

Module digest 

Compatibility re-exports of tectonic_io_base::digest types.

Structs

DigestData
A wrapper for a fixed-size byte array representing a digest computed with the default implementation.

Constants

DIGEST_LEN
The number of bytes in the digest produced by the default implementation.
DIGEST_NAME
The name of the digest algorithm used in the default implementation.

Traits

Digest
Convenience wrapper trait covering functionality of cryptographic hash functions with fixed output size.

Functions

bytes_to_hex
Convert a byte slice to its hexadecimal textual representation. Letters will be in lower case.
create
Create a new DigestComputer
hex_to_bytes
Convert a hexadecimal string to bytes.

Type Aliases

DigestComputer
SHA-256 hasher.