Module docmodel

Module docmodel 

Connecting the Tectonic document model to the engines.

This module extends the document model types provided by the tectonic_docmodel crate with the actual document-processing capabilities provided by the processing engines.

Structs

DocumentSetupOptions
Options for setting up Document instances with the driver

Traits

DocumentExt
Extension methods for Document.
WorkspaceCreatorExt
Extension methods for WorkspaceCreator.