pub struct DocumentSetupOptions { /* private fields */ }Expand description
Options for setting up Document instances with the driver
Implementations
Sourceimpl DocumentSetupOptions
impl DocumentSetupOptions
Sourcepub fn new_with_security(security: SecuritySettings) -> Self
pub fn new_with_security(security: SecuritySettings) -> Self
Create a new set of document setup options with custom security settings.
Sourcepub fn only_cached(&mut self, s: bool) -> &mut Self
pub fn only_cached(&mut self, s: bool) -> &mut Self
Specify whether any requests to the network will be made for bundle resources.
If the document’s backing bundle is not network-based, this setting will have no effect.
Sourcepub fn deterministic_mode(&mut self, s: bool) -> &mut Self
pub fn deterministic_mode(&mut self, s: bool) -> &mut Self
Specify whether we want to ensure a deterministic build environment.