WorkspaceCreatorExt

Trait WorkspaceCreatorExt 

pub trait WorkspaceCreatorExt {
    // Required method
    fn create_defaulted(
        self,
        config: &PersistentConfig,
        bundle: Option<String>,
    ) -> Result<Workspace>;
}
Extension methods for WorkspaceCreator.

Required Methods

fn create_defaulted( self, config: &PersistentConfig, bundle: Option<String>, ) -> Result<Workspace>

Create the new workspace with a good default for the bundle location.

This method is a thin wrapper on WorkspaceCreator::create that uses the current configuration to determine a good default bundle location for the main document.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl WorkspaceCreatorExt for WorkspaceCreator

Implementors