Module engines

Module engines 

Access to Tectonic’s processing backends.

These backends subsume the functionality of programs such as bibtex, xetex, and xdvipdfmx. This module is historical — the API for each of these is defined in crates with names like tectonic_engine_xetex.

Re-exports

pub use self::bibtex::BibtexEngine;

Modules

bibtex
Engine for invoking bibtex.
spx2html
Engine to convert Tectonic’s SPX format to HTML.
tex
Engine for invoking XeTeX.
xdvipdfmx
Engine for invoking xdvipdfmx.

Structs

Spx2HtmlEngine
An engine that converts SPX to HTML.
TexEngine
A struct for invoking the (Xe)TeX engine.
XdvipdfmxEngine
A struct for invoking the xdvipdfmx engine.