pub struct BibtexEngine {}Expand description
A struct for invoking the bibtex engine.
This struct has a fairly straightforward “builder” interface: you create it,
apply any settings that you wish, and eventually run the
process() method.
Implementations
Sourceimpl BibtexEngine
impl BibtexEngine
Sourcepub fn new() -> BibtexEngine
pub fn new() -> BibtexEngine
Create a new, default engine for running bibtex.
Sourcepub fn process(
&mut self,
launcher: &mut CoreBridgeLauncher<'_>,
aux: &str,
unstables: &UnstableOptions,
) -> Result<TexOutcome>
pub fn process( &mut self, launcher: &mut CoreBridgeLauncher<'_>, aux: &str, unstables: &UnstableOptions, ) -> Result<TexOutcome>
Process a document using the current engine configuration.
The launcher parameter gives overarching environmental context in which the engine will be run.
The aux parameter gives the name of the “aux” file, created by the TeX engine, that BibTeX will process.
The unstables parameter controls unstable options that may change the behavior of
bibtex.