TexOutcome

Enum TexOutcome 

pub enum TexOutcome {
    Spotless,
    Warnings,
    Errors,
}
A possible outcome from a (Xe)TeX engine invocation.

The classic TeX implementation provides a fourth outcome: “fatal error”. In Tectonic, this outcome is represented as an Err result rather than a TexOutcome.

The Errors possibility will only occur if the halt_on_error engine option is false: if it’s true, errors get upgraded to fatals.

Variants



Spotless

Nothing bad happened.



Warnings

Warnings were issued by the TeX engine. Note that, due to the ways that people are used to using TeX, warnings are extremely common in the wild. It’s rare to find a real document that doesn’t compile with warnings.



Errors

Errors were issued by the TeX engine. Note that, in TeX terminology, errors are not necessarily fatal errors: the engine will try extremely hard to proceed when it encounters them. It is not uncommon to find TeX documents in the wild that produce errors.