Module errors

Module errors 

Tectonic error types and support code.

Structs

Error
The Error type.
SyncError

Enums

ErrorKind
The kind of an error.

Traits

ChainErrCompatExt
chain_err compatibility between our old and new error types
DefinitelySame
The DefinitelySame trait is a helper trait implemented because Errors do not generically implement PartialEq. This is a bit of a drag for testing since it’s nice to be able to check if an error matches the one that’s expected. DefinitelySame addresses this by providing a weak equivalence test: definitely_same() returns true if the two values definitely are equivalent, and false otherwise. This can happen if the value are known to be different, but also if we can’t tell. It doesn’t cover all cases, but it does cover the ones that come up in our test suite.
ResultExt
Additional methods for Result, for easy interaction with this crate.

Type Aliases

ReadError
Result
Convenient wrapper around std::Result.
WriteError