pub struct Error(pub ErrorKind, _);Expand description
The Error type.
This tuple struct is made of two elements:
- an
ErrorKindwhich is used to determine the type of the error. - An internal
State, not meant for direct use outside oferror_chaininternals, containing:- a backtrace, generated when the error is created.
- an error chain, used for the implementation of
Error::cause().
Tuple Fields
0: ErrorKindThe kind of the error.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn from_kind(kind: ErrorKind) -> Error
pub fn from_kind(kind: ErrorKind) -> Error
Constructs an error from a kind, and generates a backtrace.
Sourcepub fn with_chain<E, K>(error: E, kind: K) -> Error
pub fn with_chain<E, K>(error: E, kind: K) -> Error
Constructs a chained error from another error and a kind, and generates a backtrace.
Sourcepub fn with_boxed_chain<K>(error: Box<dyn Error + Send>, kind: K) -> Error
pub fn with_boxed_chain<K>(error: Box<dyn Error + Send>, kind: K) -> Error
Construct a chained error from another boxed error and a kind, and generates a backtrace
Sourcepub fn backtrace(&self) -> Option<&Backtrace>
pub fn backtrace(&self) -> Option<&Backtrace>
Returns the backtrace associated with this error.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
A short description of the error.
This method is identical to Error::description()
Sourceimpl Error
impl Error
Sourcepub fn dump_uncolorized(&self)
pub fn dump_uncolorized(&self)
Write the information contained in this object to standard error in a somewhat user-friendly form.
The error_chain crate provides a Display impl for its Error objects
that ought to provide this functionality, but I have had enormous
trouble being able to use it. So instead we emulate their code. This
function is also paralleled by the implementation in
status::termcolor::TermcolorStatusBackend, which adds the sugar of
providing nice colorization if possible. This function should only be
used if a StatusBackend is not yet available in the running program.