try_open_file

Function try_open_file 

pub fn try_open_file<P>(path: P) -> OpenResult<File>
where P: AsRef<Path>,
Try to open a file on the fileystem, returning an OpenResult type allowing easy handling if the file was not found.