Module memory

Module memory 

MemoryIo is an IoProvider that stores “files” in in-memory buffers.

Structs

MemoryFileInfo
Information about a file created or used inside the memory-backed I/O provider.
MemoryIo
An I/O driver backed by a collection of in-memory files.

Type Aliases

MemoryFileCollection
A collection of files created or used inside a memory-backed I/O provider.