pub type MemoryFileCollection = HashMap<String, MemoryFileInfo>;Expand description
A collection of files created or used inside a memory-backed I/O provider.
Aliased Type
pub struct MemoryFileCollection { /* private fields */ }pub type MemoryFileCollection = HashMap<String, MemoryFileInfo>;A collection of files created or used inside a memory-backed I/O provider.
pub struct MemoryFileCollection { /* private fields */ }