macro_rules! ctry {
($op:expr ; $( $chain_fmt_args:expr ),*) => { ... };
}Expand description
“Chained try” — like try!, but with the ability to add context to the error message.
macro_rules! ctry {
($op:expr ; $( $chain_fmt_args:expr ),*) => { ... };
}“Chained try” — like try!, but with the ability to add context to the error message.