macro_rules! errmsg {
($( $fmt_args:expr ),*) => { ... };
}Expand description
Use string formatting to create an Error of kind
errors::ErrorKind::Msg.
macro_rules! errmsg {
($( $fmt_args:expr ),*) => { ... };
}Use string formatting to create an Error of kind
errors::ErrorKind::Msg.