tt_error_styled

Macro tt_error_styled 

macro_rules! tt_error_styled {
    ($dest:expr, $( $fmt_args:expr ),*) => { ... };
}
Show formatted text to the user, styled as an error message.

On the console, this will normally cause the printed text to show up in bright red.