tt_note

Macro tt_note 

macro_rules! tt_note {
    ($dest:expr, $( $fmt_args:expr ),*) => { ... };
    ($dest:expr, $( $fmt_args:expr ),* ; $err:expr) => { ... };
}
Report a formatted informational message to the user.

An Error object may be provided, in which case it will be shown to the user as well. Generally, though, one would expect to use tt_warning! or tt_error! if there’s an Error available.