pub enum MessageKind {
Note,
Warning,
Error,
}Expand description
A kind of status message.
Variants
Note
An informational notice.
Warning
A message about a condition that’s unexpected or undesirable, but not a showstopper.
Error
A message about a condition that is going to prevent the program from doing what the user intended.