PlainStatusBackend

Struct PlainStatusBackend 

pub struct PlainStatusBackend { /* private fields */ }
A basic status-reporting backend that prints messages via stdio.

Implementations

Source

impl PlainStatusBackend

pub fn new(chatter: ChatterLevel) -> PlainStatusBackend

Create a new backend with the specified chatter level.

To use the default chatter level, you can also use Self::default.

pub fn always_stderr(&mut self, setting: bool) -> &mut PlainStatusBackend

Configure this backend to always print to the standard error stream.

This setting can be useful if you have a program that is printing output to standard output that needs to be machine-parsable. By activating it you can ensure that any status reports don’t get mixed in with your stdout output.