User configuration settings for the Tectonic engine.
Because Tectonic has a goal of having a high level of reproducibility, we aim to avoid persistent configuration options as much as possible. But, we at least need a mechanism for specifying the default bundle to use when running the command-line client. So we begrudgingly have a little configuration.
Structs
- Bundle
Info - Information about a default bundle
- Persistent
Config - Top-level persistent configuration required for the engine