pub struct PersistentConfig { /* private fields */ }Expand description
Top-level persistent configuration required for the engine
Implementations
Sourceimpl PersistentConfig
impl PersistentConfig
Sourcepub fn open(auto_create_config_file: bool) -> Result<PersistentConfig>
pub fn open(auto_create_config_file: bool) -> Result<PersistentConfig>
Open the per-user configuration file.
This file is stored in TOML format. If the configuration file does not
exist, no error is signaled — instead, a basic default configuration
is returned. In this case, if auto_create_config_file is true, the
configuration file (and the directory containing it) will be
automatically created, filling in the default configuration. If it is
false, the default configuration is returned and the filesystem is not
modified.
Sourcepub fn default_bundle_loc(&self) -> &str
pub fn default_bundle_loc(&self) -> &str
Get the default bundle URL for this configuration
Sourcepub fn default_bundle(&self, only_cached: bool) -> Result<Box<dyn Bundle>>
pub fn default_bundle(&self, only_cached: bool) -> Result<Box<dyn Bundle>>
Attempt to open the default bundle
Sourcepub fn format_cache_path(&self) -> Result<PathBuf>
pub fn format_cache_path(&self) -> Result<PathBuf>
Get the cache directory to use for format files