The high-level Tectonic document processing interface.
The main struct in this module is ProcessingSession, which knows how to
run (and re-run if necessary) the various engines in the right order. Such a
session can be created with a ProcessingSessionBuilder, which you might
obtain from a tectonic_docmodel::document::Document using the
crate::docmodel::DocumentExt::setup_session extension method, if you’re
using the Tectonic document model. You can set one up manually if not.
For an example of how to use this module, see src/bin/tectonic/main.rs,
which contains tectonic’s main CLI program.
Structs
- Processing
Session - The ProcessingSession struct runs the whole show when we’re actually
processing a file. It understands, for example, the need to re-run the TeX
engine if the
.auxfile changed. - Processing
Session Builder - A builder-style interface for creating a
ProcessingSession.
Enums
- Output
Format - The different types of output files that tectonic knows how to produce.
- Pass
Setting - The different types of “passes” that
ProcessingSessionknows how to run. SeeProcessingSession::runfor more details.