pub fn normalize_tex_path(path: &str) -> Cow<'_, str>Expand description
Normalize a TeX path if possible, otherwise return the original path.
A TeX path is a path that obeys simplified semantics: Unix-like syntax (/
for separators, etc.), must be Unicode-able, no symlinks allowed such that
.. can be stripped lexically.