pub fn try_open_file<P>(path: P) -> OpenResult<File>Expand description
Try to open a file on the fileystem, returning an OpenResult type
allowing easy handling if the file was not found.
pub fn try_open_file<P>(path: P) -> OpenResult<File>Try to open a file on the fileystem, returning an OpenResult type
allowing easy handling if the file was not found.