MemoryIo is an IoProvider that stores “files” in in-memory buffers.
Structs
- Memory
File Info - Information about a file created or used inside the memory-backed I/O provider.
- Memory
Io - An I/O driver backed by a collection of in-memory files.
Type Aliases
- Memory
File Collection - A collection of files created or used inside a memory-backed I/O provider.