macro_rules! tt_error_styled {
($dest:expr, $( $fmt_args:expr ),*) => { ... };
}Expand description
Show formatted text to the user, styled as an error message.
On the console, this will normally cause the printed text to show up in bright red.
macro_rules! tt_error_styled {
($dest:expr, $( $fmt_args:expr ),*) => { ... };
}Show formatted text to the user, styled as an error message.
On the console, this will normally cause the printed text to show up in bright red.