pub struct UnstableOptions {
pub continue_on_errors: bool,
pub paper_size: Option<String>,
pub shell_escape: bool,
pub min_crossrefs: Option<u32>,
pub extra_search_paths: Vec<PathBuf>,
pub shell_escape_cwd: Option<String>,
pub deterministic_mode: bool,
}Expand description
Unstable options available for engine backends. These options may be added or removed in minor releases, and are not considered breaking.
These options may affect the reproducibility of built documents.
Fields
continue_on_errors: boolDon’t stop on errors - attempt to generate a document anyway, for all but the most fatal of problems.
paper_size: Option<String>Set the paper size used by the output document.
shell_escape: boolAllow using shell commands during document compilation. All shell escapes will be executed
within a custom temporary directory that lives for the duration of the compilation session.
Self::shell_escape_cwd will take precedence over this flag.
min_crossrefs: Option<u32>Minimum number of cross-references in bibtex before an item gets its own standalone entry.
extra_search_paths: Vec<PathBuf>Extra directories to search for input files during a processing session.
shell_escape_cwd: Option<String>The working directory to use for shell escapes. The directory will be preserved after
compilation is complete. This overrides Self::shell_escape.
deterministic_mode: boolEnsure a deterministic build environment.
The most significant user-facing difference is a static document build
date, but this is already covered by crate::driver::ProcessingSessionBuilder::build_date_from_env,
which accepts a deterministic flag. Additionally, deterministic mode
spoofs file modification times and hides absolute paths from the engine.
There’s a few ways to break determinism (shell escape, reading from
/dev/urandom), but anything else (especially behaviour in TeXLive
packages) is considered a bug.